==> Orders-1.13.tar.gz: Orders/action.admin_templates.php <==
<?php
#-------------------------------------------------------------------------
# Module: Orders - A simple order processing module.
# Version: 1.0, calguy1000 <calguy1000@cmsmadesimple.org>
#
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/skeleton/
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in every page of
# its admin section that the site was built with CMS Made simple, and
# provide a link to the CMS Made Simple website.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
if( !isset($gCms) ) exit;
if( !$this->CheckPermission('Modify Templates') )
  {
    die('permission denied');
  }

echo '<div class="pageoverflow" style="text-align: right; width: 80%;">'.
$this->CreateImageLink($id,'defaultadmin',$returnid,
		       $this->Lang('lbl_back'),'icons/system/back.gif',array(),'','',false).'</div><br/>';

echo $this->StartTabHeaders();
echo $this->SetTabHeader('billing',
			 $this->Lang('billing_form_templates'));
echo $this->SetTabHeader('payment',
			 $this->Lang('payment_form_templates'));
echo $this->SetTabHeader('confirmorder',
			 $this->Lang('order_confirm_form_templates'));
echo $this->SetTabHeader('invoice',
			 $this->Lang('invoice_templates'));
echo $this->SetTabHeader('gateway_complete',
			 $this->Lang('gateway_complete_templates'));
echo $this->SetTabHeader('useremail',
			 $this->Lang('user_email_template'));
echo $this->SetTabHeader('adminemail',
			 $this->Lang('admin_email_template'));
echo $this->SetTabHeader('messagetemplates',
			 $this->Lang('message_templates'));
echo $this->SetTabHeader('defaulttemplates',
			 $this->Lang('default_templates'));
echo $this->SetTabHeader('report_templates',$this->Lang('report_templates'));
echo $this->EndTabHeaders();

// tab content
echo $this->StartTabContent();

echo $this->StartTab('billing');
include(dirname(__FILE__).'/function.billing_tab.php');
echo $this->EndTab();

echo $this->StartTab('payment');
include(dirname(__FILE__).'/function.payment_tab.php');
echo $this->EndTab();

echo $this->StartTab('confirmorder');
include(dirname(__FILE__).'/function.confirmorder_tab.php');
echo $this->EndTab();

echo $this->StartTab('invoice');
include(dirname(__FILE__).'/function.invoice_tab.php');
echo $this->EndTab();

echo $this->StartTab('gateway_complete');
include(dirname(__FILE__).'/function.gateway_complete_tab.php');
echo $this->EndTab();

echo $this->StartTab('useremail');
include(dirname(__FILE__).'/function.useremail_tab.php');
echo $this->EndTab();

echo $this->StartTab('adminemail');
include(dirname(__FILE__).'/function.adminemail_tab.php');
echo $this->EndTab();
    
echo $this->StartTab('messagetemplates');
include(dirname(__FILE__).'/function.messagetemplates_tab.php');
echo $this->EndTab();

echo $this->StartTab('defaulttemplates');
include(dirname(__FILE__).'/function.defaulttemplates_tab.php');
echo $this->EndTab();

echo $this->StartTab('report_templates');
include(dirname(__FILE__).'/function.report_templates_tab.php');
echo $this->EndTab();

echo $this->EndTabContent();
// EOF
?>

==> Orders-1.13.1.tar.gz: Orders/action.admin_templates.php <==
<?php
#-------------------------------------------------------------------------
# Module: Orders - A simple order processing module.
# Version: 1.0, calguy1000 <calguy1000@cmsmadesimple.org>
#
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/skeleton/
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in every page of
# its admin section that the site was built with CMS Made simple, and
# provide a link to the CMS Made Simple website.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
if( !isset($gCms) ) exit;
if( !$this->CheckPermission('Modify Templates') )
  {
    die('permission denied');
  }

echo '<div class="pageoverflow" style="text-align: right; width: 80%;">'.
$this->CreateImageLink($id,'defaultadmin',$returnid,
		       $this->Lang('lbl_back'),'icons/system/back.gif',array(),'','',false).'</div><br/>';

echo $this->StartTabHeaders();
echo $this->SetTabHeader('billing',
			 $this->Lang('billing_form_templates'));
echo $this->SetTabHeader('shipping',
			 $this->Lang('shipping_form_templates'));
echo $this->SetTabHeader('confirmorder',
			 $this->Lang('order_confirm_form_templates'));
echo $this->SetTabHeader('invoice',
			 $this->Lang('invoice_templates'));
echo $this->SetTabHeader('gateway_complete',
			 $this->Lang('gateway_complete_templates'));
echo $this->SetTabHeader('useremail',
			 $this->Lang('user_email_template'));
echo $this->SetTabHeader('adminemail',
			 $this->Lang('admin_email_template'));
echo $this->SetTabHeader('messagetemplates',
			 $this->Lang('message_templates'));
echo $this->SetTabHeader('defaulttemplates',
			 $this->Lang('default_templates'));
echo $this->SetTabHeader('report_templates',$this->Lang('report_templates'));
echo $this->EndTabHeaders();

// tab content
echo $this->StartTabContent();

echo $this->StartTab('billing');
include(dirname(__FILE__).'/function.billing_tab.php');
echo $this->EndTab();

echo $this->StartTab('shipping');
include(dirname(__FILE__).'/function.shipping_template_tab.php');
echo $this->EndTab();

echo $this->StartTab('confirmorder');
include(dirname(__FILE__).'/function.confirmorder_tab.php');
echo $this->EndTab();

echo $this->StartTab('invoice');
include(dirname(__FILE__).'/function.invoice_tab.php');
echo $this->EndTab();

echo $this->StartTab('gateway_complete');
include(dirname(__FILE__).'/function.gateway_complete_tab.php');
echo $this->EndTab();

echo $this->StartTab('useremail');
include(dirname(__FILE__).'/function.useremail_tab.php');
echo $this->EndTab();

echo $this->StartTab('adminemail');
include(dirname(__FILE__).'/function.adminemail_tab.php');
echo $this->EndTab();
    
echo $this->StartTab('messagetemplates');
include(dirname(__FILE__).'/function.messagetemplates_tab.php');
echo $this->EndTab();

echo $this->StartTab('defaulttemplates');
include(dirname(__FILE__).'/function.defaulttemplates_tab.php');
echo $this->EndTab();

echo $this->StartTab('report_templates');
include(dirname(__FILE__).'/function.report_templates_tab.php');
echo $this->EndTab();

echo $this->EndTabContent();
// EOF
?>
